cocos.skeleton module — cocos v0.6.5 documentation

# cocos.skeleton module

class `Animate`(*args, **kwargs)

  Bases: `cocos.actions.base_actions.IntervalAction`

  `init`(animation, recenter=False, recenter_x=False, recenter_y=False)
  `start`()
  `update`(t)

class `Animation`(skeleton)

  Bases: `object`

  `delete_time`(delta)
  `flipped`()
  `get_duration`()
  `get_keyframe`(offset=0)
  `get_markers`()
  `get_position`()
  `insert_keyframe`()
  `insert_time`(delta)
  `move_end`()
  `move_position`(delta)
  `move_start`()
  `next_keyframe`()
  `pose`(who, t, start)
  `prev_keyframe`()
  `remove_keyframe`()

class `BitmapSkin`(skeleton, skin_def, alpha=255)

  Bases: `cocos.skeleton.Skin`

  `blit_image`(matrix, position, scale, image)
  `draw`()
  `flip`()
  `get_control_points`()
  `move`(idx, dx, dy)
  `regenerate`()
  `skin_parts` = []

class `Bone`(label, size, rotation, translation)

  Bases: `object`

  `add`(bone)
  `dump`(depth=0)
  `flipped`()
  `get_end`()
  `get_start`()
  `interpolated_to`(next, delta)
  `move`(dx, dy)
  `repr`(depth=0)
  `rotate`(angle)

class `ColorSkin`(skeleton, color)

  Bases: `cocos.skeleton.Skin`

  `draw`()
  `draw_bone`(bone)

class `Skeleton`(bone)

  Bases: `object`

  `flipped`()
  `get_control_points`()
  `interpolated_to`(next, delta)
  `move`(dx, dy)
  `pose_from`(other)
  `propagate_matrix`()
  `save`(name)
  `visit_children`(func)

class `Skin`(skeleton)

  Bases: `cocos.cocosnode.CocosNode`